# Pear Chat

P2P terminal chat for local networks.

<img width="1510" alt="image" src="https://github.com/user-attachments/assets/
aa79773c-2e4c-435e-9fad-e0079dd168a6" />

## Install

```bash
pip install pear-chat
```

## Usage

```bash
# Start a session
pear start mysession

# Join a session
pear join mysession

# List available sessions
pear list

# Set username for future sessions
pear login myusername
```
